%define anolis_release 2
%global modname pycurl

Name:           python-%{modname}
Version:        7.45.2
Release:        %{anolis_release}%{?dist}
Summary:        A Python interface to libcurl

License:        LGPLv2+ or MIT
URL:            http://pycurl.io/
Source0:        https://files.pythonhosted.org/packages/47/f9/c41d6830f7bd4e70d5726d26f8564538d08ca3a7ac3db98b325f94cdcb7f/pycurl-%{version}.tar.gz

# drop link-time vs. run-time TLS backend check (#1446850)
Patch1:         0001-python-pycurl-7.45.1-tls-backend.patch
Patch2:		0002-python-pycurl-7.45.2-disable-test_http_version_3.patch

BuildRequires:  gcc
BuildRequires:  libcurl-devel
BuildRequires:  make
BuildRequires:  openssl-devel
BuildRequires:  vsftpd

# During its initialization, PycURL checks that the actual libcurl version
# is not lower than the one used when PycURL was built.
# Yes, that should be handled by library versioning (which would then get
# automatically reflected by rpm).
# For now, we have to reflect that dependency.
%global libcurl_sed '/^#define LIBCURL_VERSION "/!d;s/"[^"]*$//;s/.*"//;q'
%global curlver_h /usr/include/curl/curlver.h
%global libcurl_ver %(sed %{libcurl_sed} %{curlver_h} 2>/dev/null || echo 0)

%description
PycURL is a Python interface to libcurl. PycURL can be used to fetch
objects identified by a URL from a Python program, similar to the
urllib Python module. PycURL is mature, very fast, and supports a lot
of features.

%package -n python3-%{modname}
Summary:        Python interface to libcurl for Python 3
%{?python_provide:%python_provide python3-%{modname}}
BuildRequires:  python3-devel
BuildRequires:  python3-bottle
BuildRequires:  python3-flaky
BuildRequires:  python3-pytest
%global pytest pytest
BuildRequires:  python3-setuptools
Requires:       libcurl >= %{libcurl_ver}

%description -n python3-%{modname}
PycURL is a Python interface to libcurl. PycURL can be used to fetch
objects identified by a URL from a Python program, similar to the
urllib Python module. PycURL is mature, very fast, and supports a lot
of features.

%prep
%autosetup -n %{modname}-%{version} -p1

# remove windows-specific build script
rm -fv winbuild.py

sed -e 's|python |%{python3} |' -i tests/ext/test-suite.sh
sed -e 's|^#! */usr/bin/env python$|#! /usr/bin/env %{python3}|' \
    -i tests/*.py setup.py

%build
%py3_build -- --with-openssl

%install
export PYCURL_SSL_LIBRARY=openssl
%py3_install
rm -rf %{buildroot}%{_datadir}/doc/pycurl

%check
# relax crypto policy for the test-suite to make it pass again
export OPENSSL_SYSTEM_CIPHERS_OVERRIDE=XXX
export OPENSSL_CONF=

export PYTHONPATH=%{buildroot}%{python3_sitearch}
export PYCURL_SSL_LIBRARY=openssl
export PYCURL_VSFTPD_PATH=vsftpd
export PYTEST_ADDOPTS="--ignore examples -m 'not online'"
make test PYTHON=%{__python3} PYTEST=%{pytest} PYFLAKES=true
rm -fv tests/fake-curl/libcurl/*.so
rm -fvr tests/__pycache__

%files -n python3-%{modname}
%license COPYING-LGPL COPYING-MIT
%doc ChangeLog README.rst examples doc tests
%{python3_sitearch}/curl/
%{python3_sitearch}/%{modname}.*.so
%{python3_sitearch}/%{modname}-%{version}-*.egg-info

%changelog
* Tue Nov  7 2023 Wenlong Zhang<zhangwenlong@loongson.cn> - 7.45.2-2
- fix build error for python-pycurl

* Wed Dec 21 2022 Funda Wang <fundawang@yeah.net> - 7.45.2-1
- New version 7.45.2

* Thu Apr 28 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 7.45.1-1
- Init from upstream version 7.45.1
